@@ -1,5 +1,7 @@
 package Graph::TransitiveClosure;
 
+use strict;
+
 # COMMENT THESE OUT FOR TESTING AND PRODUCTION.
 # $SIG{__DIE__ } = sub { use Carp; confess };
 # $SIG{__WARN__} = sub { use Carp; confess };
@@ -48,12 +50,13 @@ sub new {
 	    }
 	}
     }
-    $tcm->set_graph_attribute('_tcm', $tcg); # Duplicate?
+    $tcm->set_graph_attribute('_tcm', $tcg);
     bless $tcm, $class;
 }
 
 sub is_transitive {
     my $g = shift;
+    $g->expect_no_args(@_);
     Graph::TransitiveClosure::Matrix::is_transitive($g);
 }
 
@@ -61,6 +64,8 @@ sub is_transitive {
 __END__
 =pod
 
+=head1 NAME
+
 Graph::TransitiveClosure - create and query transitive closure of graph
 
 =head1 SYNOPSIS
@@ -83,10 +88,6 @@ Graph::TransitiveClosure - create and query transitive closure of graph
     # is_reachable(u, v) is always reflexive.
     $tcg->is_reachable($u, $v)
 
-    # The reflexivity of is_transitive(u, v) depends of the reflexivity
-    # of the transitive closure.
-    $tcg->is_transitive($u, $v)
-
     # You can check any graph for transitivity.
     $g->is_transitive()
 
